# pymwalib
![Tests](https://github.com/MWATelescope/pymwalib/workflows/Code%20Coverage/badge.svg)
[![codecov](https://codecov.io/gh/MWATelescope/pymwalib/branch/master/graph/badge.svg)](https://codecov.io/gh/MWATelescope/pymwalib)
A Python interface for [MWATelescope/mwalib](https://github.com/MWATelescope/mwalib) that provides a simple
interface for reading MWA correlator raw visibilities, recombined voltages and exposing the relevant metadata. pymwalib and mwalib
both support reading data produced by the existing (legacy) MWA and the new MWAX systems.

See [pymwalib Wiki](https://github.com/MWATelescope/pymwalib/wiki) for installation and usage infomation.
